package com.taais.biz.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import com.taais.common.core.exception.ServiceException;
import com.taais.common.core.utils.SpringUtils;
import com.taais.common.core.utils.ValidatorUtils;
import com.taais.common.excel.core.ExcelListener;
import com.taais.common.excel.core.ExcelResult;
import com.taais.biz.domain.bo.AlgorithmDataSetBo;
import com.taais.biz.domain.vo.AlgorithmDataSetImportVo;
import com.taais.biz.domain.vo.AlgorithmDataSetVo;
import com.taais.biz.service.IAlgorithmDataSetService;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

/**
 * 算法数据集合自定义导入
 *
 * @author km
 */
@Slf4j
public class AlgorithmDataSetImportListener extends AnalysisEventListener<AlgorithmDataSetImportVo> implements ExcelListener<AlgorithmDataSetImportVo> {
    private final IAlgorithmDataSetService algorithmDataSetService;

    private final Boolean isUpdateSupport;
    private int successNum = 0;
    private int failureNum = 0;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();

    public AlgorithmDataSetImportListener(Boolean isUpdateSupport) {
        this.algorithmDataSetService = SpringUtils.getBean(IAlgorithmDataSetService.class);
        this.isUpdateSupport = isUpdateSupport;
    }

    @Override
    public void invoke(AlgorithmDataSetImportVo algorithmDataSetVo, AnalysisContext context) {
        try {

            AlgorithmDataSetBo algorithmDataSetBo = BeanUtil.toBean(algorithmDataSetVo, AlgorithmDataSetBo.class);

            //TODO:根据某个字段，查询数据库表中是否存在记录，不存在就新增，存在就更新
            AlgorithmDataSetVo algorithmDataSetVo1 = null;

            //algorithmDataSetVo1 = algorithmDataSetService.selectBySomefield(algorithmDataSetVo.getSomefield());
            if (ObjectUtil.isNull(algorithmDataSetVo1)) {
                //不存在就新增
                algorithmDataSetBo.setVersion(0);
                ValidatorUtils.validate(algorithmDataSetBo);
                boolean inserted = algorithmDataSetService.insert(algorithmDataSetBo);

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、算法数据集合 记录导入成功");
                    return;
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、算法数据集合 记录导入失败");
                    return;
                }
            } else if (isUpdateSupport) {
                //存在就更新
                algorithmDataSetBo.setId(algorithmDataSetVo1.getId());//主键
                algorithmDataSetBo.setVersion(algorithmDataSetVo1.getVersion());
                boolean updated = algorithmDataSetService.update(algorithmDataSetBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、算法数据集合 记录更新成功");
                    return;
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、算法数据集合 记录更新失败");
                    return;
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、算法数据集合 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {

    }

    @Override
    public ExcelResult<AlgorithmDataSetImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public String getAnalysis() {
                if (failureNum > 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    throw new ServiceException(failureMsg.toString());
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                }
                return successMsg.toString();
            }

            @Override
            public List<AlgorithmDataSetImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
