package com.taais.biz.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import com.taais.common.core.exception.ServiceException;
import com.taais.common.core.utils.SpringUtils;
import com.taais.common.core.utils.ValidatorUtils;
import com.taais.common.excel.core.ExcelListener;
import com.taais.common.excel.core.ExcelResult;
import com.taais.biz.domain.bo.AlgorithmModelBo;
import com.taais.biz.domain.vo.AlgorithmModelImportVo;
import com.taais.biz.domain.vo.AlgorithmModelVo;
import com.taais.biz.service.IAlgorithmModelService;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

/**
 * 算法模型配置自定义导入
 *
 * @author 0
 */
@Slf4j
public class AlgorithmModelImportListener extends AnalysisEventListener<AlgorithmModelImportVo> implements ExcelListener<AlgorithmModelImportVo> {
    private final IAlgorithmModelService algorithmModelService;

    private final Boolean isUpdateSupport;
    private int successNum = 0;
    private int failureNum = 0;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();

    public AlgorithmModelImportListener(Boolean isUpdateSupport) {
        this.algorithmModelService = SpringUtils.getBean(IAlgorithmModelService.class);
        this.isUpdateSupport = isUpdateSupport;
    }

    @Override
    public void invoke(AlgorithmModelImportVo algorithmModelVo, AnalysisContext context) {
        try {

            AlgorithmModelBo algorithmModelBo = BeanUtil.toBean(algorithmModelVo, AlgorithmModelBo.class);

            //TODO:根据某个字段，查询数据库表中是否存在记录，不存在就新增，存在就更新
            AlgorithmModelVo algorithmModelVo1 = null;

            //algorithmModelVo1 = algorithmModelService.selectBySomefield(algorithmModelVo.getSomefield());
            if (ObjectUtil.isNull(algorithmModelVo1)) {
                //不存在就新增
                algorithmModelBo.setVersion(0);
                ValidatorUtils.validate(algorithmModelBo);
                boolean inserted = algorithmModelService.insert(algorithmModelBo);

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、算法模型配置 记录导入成功");
                    return;
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、算法模型配置 记录导入失败");
                    return;
                }
            } else if (isUpdateSupport) {
                //存在就更新
                algorithmModelBo.setId(algorithmModelVo1.getId());//主键
                algorithmModelBo.setVersion(algorithmModelVo1.getVersion());
                boolean updated = algorithmModelService.update(algorithmModelBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、算法模型配置 记录更新成功");
                    return;
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、算法模型配置 记录更新失败");
                    return;
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、算法模型配置 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {

    }

    @Override
    public ExcelResult<AlgorithmModelImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public String getAnalysis() {
                if (failureNum > 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    throw new ServiceException(failureMsg.toString());
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                }
                return successMsg.toString();
            }

            @Override
            public List<AlgorithmModelImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
