package com.taais.biz.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import com.taais.biz.domain.bo.Video2imageBo;
import com.taais.biz.domain.vo.Video2imageImportVo;
import com.taais.biz.domain.vo.Video2imageVo;
import com.taais.biz.service.IVideo2imageService;
import com.taais.common.core.exception.ServiceException;
import com.taais.common.core.utils.SpringUtils;
import com.taais.common.core.utils.ValidatorUtils;
import com.taais.common.excel.core.ExcelListener;
import com.taais.common.excel.core.ExcelResult;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

/**
 * 视频转图片自定义导入
 *
 * @author km
 */
@Slf4j
public class Video2imageImportListener extends AnalysisEventListener<Video2imageImportVo> implements ExcelListener<Video2imageImportVo> {
    private final IVideo2imageService video2imageService;

    private final Boolean isUpdateSupport;
    private int successNum = 0;
    private int failureNum = 0;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();

    public Video2imageImportListener(Boolean isUpdateSupport) {
        this.video2imageService = SpringUtils.getBean(IVideo2imageService.class);
        this.isUpdateSupport = isUpdateSupport;
    }

    @Override
    public void invoke(Video2imageImportVo video2imageVo, AnalysisContext context) {
        try {

            Video2imageBo video2imageBo = BeanUtil.toBean(video2imageVo, Video2imageBo.class);

            //TODO:根据某个字段，查询数据库表中是否存在记录，不存在就新增，存在就更新
            Video2imageVo video2imageVo1 = null;

            //video2imageVo1 = video2imageService.selectBySomefield(video2imageVo.getSomefield());
            if (ObjectUtil.isNull(video2imageVo1)) {
                //不存在就新增
                video2imageBo.setVersion(0);
                ValidatorUtils.validate(video2imageBo);
                boolean inserted = video2imageService.insert(video2imageBo);

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、视频转图片 记录导入成功");
                    return;
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、视频转图片 记录导入失败");
                    return;
                }
            } else if (isUpdateSupport) {
                //存在就更新
                video2imageBo.setId(video2imageVo1.getId());//主键
                video2imageBo.setVersion(video2imageVo1.getVersion());
                boolean updated = video2imageService.update(video2imageBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、视频转图片 记录更新成功");
                    return;
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、视频转图片 记录更新失败");
                    return;
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、视频转图片 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {

    }

    @Override
    public ExcelResult<Video2imageImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public String getAnalysis() {
                if (failureNum > 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    throw new ServiceException(failureMsg.toString());
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                }
                return successMsg.toString();
            }

            @Override
            public List<Video2imageImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
