package com.taais.biz.service;

import java.io.IOException;
import java.util.List;

import com.taais.biz.domain.AlgorithmBizProcess;
import com.taais.biz.domain.dto.TaskResultDTO;
import com.taais.biz.domain.dto.task.TestResultDto;
import com.taais.biz.domain.dto.task.TranResultDto;
import com.taais.biz.domain.vo.AlgorithmBizProcessVo;
import com.taais.biz.domain.bo.AlgorithmBizProcessBo;
import com.taais.common.orm.core.service.IBaseService;
import com.taais.common.core.core.page.PageResult;

/**
 * 算法业务处理Service接口
 *
 * @author 0
 * 2024-06-14
 */
public interface IAlgorithmBizProcessService extends IBaseService<AlgorithmBizProcess> {
    /**
     * 查询算法业务处理
     *
     * @param id 算法业务处理主键
     * @return 算法业务处理
     */
        AlgorithmBizProcessVo selectById(Long id);

    /**
     * 查询算法业务处理列表
     *
     * @param algorithmBizProcessBo 算法业务处理Bo
     * @return 算法业务处理集合
     */
    List<AlgorithmBizProcessVo> selectList(AlgorithmBizProcessBo algorithmBizProcessBo);

    /**
     * 分页查询算法业务处理列表
     *
     * @param algorithmBizProcessBo 算法业务处理Bo
     * @return 分页算法业务处理集合
     */
    PageResult<AlgorithmBizProcessVo> selectPage(AlgorithmBizProcessBo algorithmBizProcessBo);

    /**
     * 新增算法业务处理
     *
     * @param algorithmBizProcessBo 算法业务处理Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(AlgorithmBizProcessBo algorithmBizProcessBo);

    /**
     * 修改算法业务处理
     *
     * @param algorithmBizProcessBo 算法业务处理Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(AlgorithmBizProcessBo algorithmBizProcessBo);

    /**
     * 批量删除算法业务处理
     *
     * @param ids 需要删除的算法业务处理主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    List<AlgorithmBizProcessVo> getStatus0ProcessBySubtaskId(Long subtaskId);


    List<AlgorithmBizProcessVo> getProcessBySubtaskId(Long subtaskId);

    String taskResult(TaskResultDTO resultDTO);

    TranResultDto getTranResult(Long subtaskId);

    TestResultDto getTestResult(Long subtaskId) throws IOException;

}
