package com.taais.biz.service;

import java.util.List;

import com.taais.biz.domain.AlgorithmDataSet;
import com.taais.biz.domain.vo.AlgorithmDataSetVo;
import com.taais.biz.domain.bo.AlgorithmDataSetBo;
import com.taais.common.orm.core.service.IBaseService;
import com.taais.common.core.core.page.PageResult;

/**
 * 算法数据集合Service接口
 *
 * @author km
 * 2024-06-14
 */
public interface IAlgorithmDataSetService extends IBaseService<AlgorithmDataSet> {
    /**
     * 查询算法数据集合
     *
     * @param id 算法数据集合主键
     * @return 算法数据集合
     */
        AlgorithmDataSetVo selectById(Long id);

    /**
     * 查询算法数据集合列表
     *
     * @param algorithmDataSetBo 算法数据集合Bo
     * @return 算法数据集合集合
     */
    List<AlgorithmDataSetVo> selectList(AlgorithmDataSetBo algorithmDataSetBo);

    /**
     * 分页查询算法数据集合列表
     *
     * @param algorithmDataSetBo 算法数据集合Bo
     * @return 分页算法数据集合集合
     */
    PageResult<AlgorithmDataSetVo> selectPage(AlgorithmDataSetBo algorithmDataSetBo);

    /**
     * 新增算法数据集合
     *
     * @param algorithmDataSetBo 算法数据集合Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(AlgorithmDataSetBo algorithmDataSetBo);

    /**
     * 修改算法数据集合
     *
     * @param algorithmDataSetBo 算法数据集合Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(AlgorithmDataSetBo algorithmDataSetBo);

    /**
     * 批量删除算法数据集合
     *
     * @param ids 需要删除的算法数据集合主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

}
