package com.taais.biz.service;

import java.util.List;

import com.taais.biz.domain.AlgorithmSubtask;
import com.taais.biz.domain.vo.AlgorithmSubtaskVo;
import com.taais.biz.domain.bo.AlgorithmSubtaskBo;
import com.taais.common.orm.core.service.IBaseService;
import com.taais.common.core.core.page.PageResult;

/**
 * 算法子任务Service接口
 *
 * @author Allen
 * 2024-06-11
 */
public interface IAlgorithmSubtaskService extends IBaseService<AlgorithmSubtask> {
    /**
     * 查询算法子任务
     *
     * @param id 算法子任务主键
     * @return 算法子任务
     */
        AlgorithmSubtaskVo selectById(Long id);

    /**
     * 查询算法子任务列表
     *
     * @param algorithmSubtaskBo 算法子任务Bo
     * @return 算法子任务集合
     */
    List<AlgorithmSubtaskVo> selectList(AlgorithmSubtaskBo algorithmSubtaskBo);

    /**
     * 分页查询算法子任务列表
     *
     * @param algorithmSubtaskBo 算法子任务Bo
     * @return 分页算法子任务集合
     */
    PageResult<AlgorithmSubtaskVo> selectPage(AlgorithmSubtaskBo algorithmSubtaskBo);

    /**
     * 新增算法子任务
     *
     * @param algorithmSubtaskBo 算法子任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(AlgorithmSubtaskBo algorithmSubtaskBo);

    /**
     * 修改算法子任务
     *
     * @param algorithmSubtaskBo 算法子任务Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(AlgorithmSubtaskBo algorithmSubtaskBo);

    /**
     * 批量删除算法子任务
     *
     * @param ids 需要删除的算法子任务主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    void subtaskRun(Long taskId);

    List<AlgorithmSubtaskVo> getSubtaskByTaskId(Long taskId);
}
