package com.taais.biz.service;

import java.util.List;

import com.taais.biz.domain.AlgorithmTaskConfiguration;
import com.taais.biz.domain.bo.AlgorithmTaskConfigurationParam;
import com.taais.biz.domain.vo.AlgorithmTaskConfigurationVo;
import com.taais.biz.domain.bo.AlgorithmTaskConfigurationBo;
import com.taais.common.core.core.domain.CommonResult;
import com.taais.common.orm.core.service.IBaseService;
import com.taais.common.core.core.page.PageResult;

/**
 * 算法任务Service接口
 *
 * @author 0
 * 2024-08-23
 */
public interface IAlgorithmTaskConfigurationService extends IBaseService<AlgorithmTaskConfiguration> {
    /**
     * 查询算法任务
     *
     * @param id 算法任务主键
     * @return 算法任务
     */
        AlgorithmTaskConfigurationVo selectById(Long id);

    /**
     * 查询算法任务列表
     *
     * @param algorithmTaskConfigurationBo 算法任务Bo
     * @return 算法任务集合
     */
    List<AlgorithmTaskConfigurationVo> selectList(AlgorithmTaskConfigurationBo algorithmTaskConfigurationBo);

    /**
     * 分页查询算法任务列表
     *
     * @param algorithmTaskConfigurationBo 算法任务Bo
     * @return 分页算法任务集合
     */
    PageResult<AlgorithmTaskConfigurationVo> selectPage(AlgorithmTaskConfigurationBo algorithmTaskConfigurationBo);

    /**
     * 新增算法任务
     *
     * @param algorithmTaskConfigurationBo 算法任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(AlgorithmTaskConfigurationBo algorithmTaskConfigurationBo);

    /**
     * 修改算法任务
     *
     * @param algorithmTaskConfigurationBo 算法任务Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(AlgorithmTaskConfigurationBo algorithmTaskConfigurationBo);

    /**
     * 批量删除算法任务
     *
     * @param ids 需要删除的算法任务主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    boolean insertExistedModel(AlgorithmTaskConfigurationParam param);
}
