package com.taais.biz.service;

import java.util.List;

import com.taais.biz.domain.AlgorithmTask;
import com.taais.biz.domain.dto.task.CreateTaskDto;
import com.taais.biz.domain.vo.AlgorithmTaskVo;
import com.taais.biz.domain.bo.AlgorithmTaskBo;
import com.taais.common.orm.core.service.IBaseService;
import com.taais.common.core.core.page.PageResult;

/**
 * 算法任务Service接口
 *
 * @author Allen
 * 2024-05-29
 */
public interface IAlgorithmTaskService extends IBaseService<AlgorithmTask> {

    /**
     * 查询算法任务
     *
     * @param id 算法任务主键
     * @return 算法任务
     */
    AlgorithmTaskVo selectById(Long id);

    /**
     * 查询算法任务列表
     *
     * @param algorithmTaskBo 算法任务Bo
     * @return 算法任务集合
     */
    List<AlgorithmTaskVo> selectList(AlgorithmTaskBo algorithmTaskBo);

    /**
     * 分页查询算法任务列表
     *
     * @param algorithmTaskBo 算法任务Bo
     * @return 分页算法任务集合
     */
    PageResult<AlgorithmTaskVo> selectPage(AlgorithmTaskBo algorithmTaskBo);

    /**
     * 新增算法任务
     *
     * @param algorithmTaskBo 算法任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(AlgorithmTaskBo algorithmTaskBo);

    /**
     * 修改算法任务
     *
     * @param algorithmTaskBo 算法任务Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(AlgorithmTaskBo algorithmTaskBo);

    /**
     * 批量删除算法任务
     *
     * @param ids 需要删除的算法任务主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 新增算法任务
     *
     * @param taskDto 算法任务Dto
     * @return 结果:true 操作成功，false 操作失败
     */
    String create(CreateTaskDto taskDto);

    void taskRun();
}
