package com.taais.biz.service;

import java.util.List;

import com.taais.biz.domain.TargetIdentificationSubtask;
import com.taais.biz.domain.TargetIdentificationTask;
import com.taais.biz.domain.vo.TargetIdentificationSubtaskVo;
import com.taais.biz.domain.bo.TargetIdentificationSubtaskBo;
import com.taais.common.core.utils.MapstructUtils;
import com.taais.common.orm.core.service.IBaseService;
import com.taais.common.core.core.page.PageResult;

/**
 * 目标识别子任务Service接口
 *
 * @author Allen
 * 2024-08-17
 */
public interface ITargetIdentificationSubtaskService extends IBaseService<TargetIdentificationSubtask> {
    /**
     * 查询目标识别子任务
     *
     * @param id 目标识别子任务主键
     * @return 目标识别子任务
     */
        TargetIdentificationSubtaskVo selectById(Long id);

    /**
     * 查询目标识别子任务列表
     *
     * @param targetIdentificationSubtaskBo 目标识别子任务Bo
     * @return 目标识别子任务集合
     */
    List<TargetIdentificationSubtaskVo> selectList(TargetIdentificationSubtaskBo targetIdentificationSubtaskBo);

    /**
     * 分页查询目标识别子任务列表
     *
     * @param targetIdentificationSubtaskBo 目标识别子任务Bo
     * @return 分页目标识别子任务集合
     */
    PageResult<TargetIdentificationSubtaskVo> selectPage(TargetIdentificationSubtaskBo targetIdentificationSubtaskBo);

    /**
     * 新增目标识别子任务
     *
     * @param targetIdentificationSubtaskBo 目标识别子任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(TargetIdentificationSubtaskBo targetIdentificationSubtaskBo);

    TargetIdentificationSubtask insertSubtask(TargetIdentificationSubtaskBo targetIdentificationSubtaskBo);

    /**
     * 修改目标识别子任务
     *
     * @param targetIdentificationSubtaskBo 目标识别子任务Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(TargetIdentificationSubtaskBo targetIdentificationSubtaskBo);

    /**
     * 批量删除目标识别子任务
     *
     * @param ids 需要删除的目标识别子任务主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    void taskRun(TargetIdentificationTask task);
}
