package com.taais.biz.service;

import java.util.List;

import com.taais.biz.domain.TargetIdentificationTask;
import com.taais.biz.domain.dto.task.CreateTargetIdentificationTaskDto;
import com.taais.biz.domain.vo.TargetIdentificationTaskVo;
import com.taais.biz.domain.bo.TargetIdentificationTaskBo;
import com.taais.common.orm.core.service.IBaseService;
import com.taais.common.core.core.page.PageResult;

/**
 * 目标识别任务Service接口
 *
 * @author km
 * 2024-08-17
 */
public interface ITargetIdentificationTaskService extends IBaseService<TargetIdentificationTask> {
    /**
     * 查询目标识别任务
     *
     * @param id 目标识别任务主键
     * @return 目标识别任务
     */
        TargetIdentificationTaskVo selectById(Long id);

    /**
     * 查询目标识别任务列表
     *
     * @param targetIdentificationTaskBo 目标识别任务Bo
     * @return 目标识别任务集合
     */
    List<TargetIdentificationTaskVo> selectList(TargetIdentificationTaskBo targetIdentificationTaskBo);

    /**
     * 分页查询目标识别任务列表
     *
     * @param targetIdentificationTaskBo 目标识别任务Bo
     * @return 分页目标识别任务集合
     */
    PageResult<TargetIdentificationTaskVo> selectPage(TargetIdentificationTaskBo targetIdentificationTaskBo);

    /**
     * 新增目标识别任务
     *
     * @param targetIdentificationTaskBo 目标识别任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(TargetIdentificationTaskBo targetIdentificationTaskBo);

    /**
     * 修改目标识别任务
     *
     * @param targetIdentificationTaskBo 目标识别任务Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(TargetIdentificationTaskBo targetIdentificationTaskBo);

    /**
     * 批量删除目标识别任务
     *
     * @param ids 需要删除的目标识别任务主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    String createTask(CreateTargetIdentificationTaskDto o);

    void taskRun();
}
