package com.taais.biz.service;

import com.taais.biz.domain.Video2image;
import com.taais.biz.domain.bo.Video2imageBo;
import com.taais.biz.domain.vo.Video2imageVo;
import com.taais.common.core.core.page.PageResult;
import com.taais.common.orm.core.service.IBaseService;
import org.springframework.core.io.Resource;
import org.springframework.http.ResponseEntity;

import java.util.List;

/**
 * 视频转图片 Service接口
 *
 * @author km
 * 2024-08-16
 */
public interface IVideo2imageService extends IBaseService<Video2image> {
    /**
     * 查询视频转图片
     *
     * @param id 视频转图片主键
     * @return 视频转图片
     */
    Video2imageVo selectById(Long id);

    /**
     * 查询视频转图片列表
     *
     * @param video2imageBo 视频转图片Bo
     * @return 视频转图片集合
     */
    List<Video2imageVo> selectList(Video2imageBo video2imageBo);

    /**
     * 分页查询视频转图片列表
     *
     * @param video2imageBo 视频转图片Bo
     * @return 分页视频转图片集合
     */
    PageResult<Video2imageVo> selectPage(Video2imageBo video2imageBo);

    /**
     * 新增视频转图片
     *
     * @param video2imageBo 视频转图片Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(Video2imageBo video2imageBo);

    /**
     * 修改视频转图片
     *
     * @param video2imageBo 视频转图片Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(Video2imageBo video2imageBo);

    /**
     * 批量删除视频转图片
     *
     * @param ids 需要删除的视频转图片主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    boolean startToImage(Long id);

    ResponseEntity<Resource> zipImages(Long id);

    boolean stopToImage(Long id);
}
